@@ -21,6 +21,7 @@
 #define HAVE_NAN 1
 #define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
 #define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
+#define BROKEN_CRYPT 1
 #define HAVE_CRT_EXTERNS_H 1
 #define HAVE_LIBDL 1
 #define HAVE_DIRENT_H 1
@@ -57,6 +58,7 @@
 #define SIZEOF_LONG 8
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
+#define SIZEOF___INT128 16
 #define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 8
 #define SIZEOF_FLOAT 4
@@ -64,7 +66,7 @@
 #define SIZEOF_TIME_T 8
 #define SIZEOF_CLOCK_T 8
 #define PACKED_STRUCT(x) x __attribute__((packed))
-#define PACKED_STRUCT_UNALIGNED(x) x
+#define USE_UNALIGNED_MEMBER_ACCESS 1
 #define PRI_LL_PREFIX "ll"
 #define rb_pid_t pid_t
 #define SIGNEDNESS_OF_PID_T -1
@@ -116,18 +118,23 @@
 #define STRINGIZE(expr) STRINGIZE0(expr)
 #define HAVE_STDARG_PROTOTYPES 1
 #define HAVE_VA_ARGS_MACRO 1
-#define NORETURN(x) __attribute__ ((noreturn)) x
-#define DEPRECATED(x) __attribute__ ((deprecated)) x
-#define DEPRECATED_BY(n,x) __attribute__ ((deprecated("by "#n))) x
-#define DEPRECATED_TYPE(mesg,x) x __attribute__ ((deprecated mesg))
-#define NOINLINE(x) __attribute__ ((noinline)) x
-#define WEAK(x) __attribute__ ((weak)) x
+#define CONSTFUNC(x) __attribute__ ((__const__)) x
+#define PUREFUNC(x) __attribute__ ((__pure__)) x
+#define NORETURN(x) __attribute__ ((__noreturn__)) x
+#define DEPRECATED(x) __attribute__ ((__deprecated__)) x
+#define DEPRECATED_BY(n,x) __attribute__ ((__deprecated__("by "#n))) x
+#define DEPRECATED_TYPE(mesg,x) x __attribute__ ((__deprecated__ mesg))
+#define NOINLINE(x) __attribute__ ((__noinline__)) x
+#define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
+#define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
+#define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
+#define WEAK(x) __attribute__ ((__weak__)) x
 #define HAVE_FUNC_WEAK 1
-#define FUNC_CDECL(x) __attribute__ ((cdecl)) x
+#define FUNC_CDECL(x) __attribute__ ((__cdecl__)) x
 #define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define UNREACHABLE __builtin_unreachable()
-#define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
+#define RUBY_FUNC_EXPORTED __attribute__ ((__visibility__("default"))) extern
 #define RUBY_FUNCTION_NAME_STRING __func__
 #define ENUM_OVER_INT 1
 #define HAVE_DECL_SYS_NERR 1
@@ -170,6 +177,12 @@
 #define SIZEOF_INT64_T 8
 #define HAVE_UINT64_T 1
 #define SIZEOF_UINT64_T 8
+#define HAVE_INT128_T 1
+#define int128_t __int128
+#define SIZEOF_INT128_T SIZEOF___INT128
+#define HAVE_UINT128_T 1
+#define uint128_t unsigned __int128
+#define SIZEOF_UINT128_T SIZEOF___INT128
 #define HAVE_INTPTR_T 1
 #define SIZEOF_INTPTR_T 8
 #define HAVE_UINTPTR_T 1
@@ -206,7 +219,7 @@
 #define vfork fork
 #define HAVE_WORKING_FORK 1
 #define HAVE__LONGJMP 1
-#define HAVE__SETJMP 1
+#define HAVE_ARC4RANDOM_BUF 1
 #define HAVE_ATAN2L 1
 #define HAVE_ATAN2F 1
 #define HAVE_CHROOT 1
@@ -220,8 +233,10 @@
 #define HAVE_FCHMOD 1
 #define HAVE_FCHOWN 1
 #define HAVE_FCNTL 1
+#define HAVE_FDOPENDIR 1
 #define HAVE_FGETATTRLIST 1
 #define HAVE_FMOD 1
+#define HAVE_FSTATAT 1
 #define HAVE_FSYNC 1
 #define HAVE_FTRUNCATE 1
 #define HAVE_GETATTRLIST 1
@@ -248,6 +263,7 @@
 #define HAVE_LOCKF 1
 #define HAVE_LOG2 1
 #define HAVE_LSTAT 1
+#define HAVE_LUTIMES 1
 #define HAVE_MALLOC_SIZE 1
 #define HAVE_MBLEN 1
 #define HAVE_MEMSET_S 1
@@ -255,9 +271,11 @@
 #define HAVE_MKFIFO 1
 #define HAVE_MKNOD 1
 #define HAVE_MKTIME 1
+#define HAVE_OPENAT 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_MEMALIGN 1
 #define HAVE_PREAD 1
+#define HAVE_PWRITE 1
 #define HAVE_QSORT_R 1
 #define HAVE_READLINK 1
 #define HAVE_ROUND 1
@@ -300,26 +318,30 @@
 #define HAVE_BUILTIN___BUILTIN_BSWAP16 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP32 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP64 1
+#define HAVE_BUILTIN___BUILTIN_POPCOUNT 1
+#define HAVE_BUILTIN___BUILTIN_POPCOUNTLL 1
 #define HAVE_BUILTIN___BUILTIN_CLZ 1
 #define HAVE_BUILTIN___BUILTIN_CLZL 1
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
+#define HAVE_BUILTIN___BUILTIN_CTZ 1
+#define HAVE_BUILTIN___BUILTIN_CTZLL 1
+#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define HAVE_BSD_QSORT_R 1
 #define ATAN2_INF_C99 1
-#define LGAMMA_R_PM0_FIX 1
 #define HAVE_CLOCK_GETRES 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
 #define HAVE_DAYLIGHT 1
-#define HAVE_VAR_TIMEZONE 1
-#define TYPEOF_VAR_TIMEZONE long
-#define HAVE_TIMEZONE 1
-#define TIMEZONE_VOID 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
+#define HAVE_SIG_T 1
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
@@ -329,13 +351,13 @@
 #define HAVE_SCHED_YIELD 1
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
+#define HAVE_PTHREAD_ATTR_INIT 1
 #define HAVE_PTHREAD_GET_STACKADDR_NP 1
 #define HAVE_PTHREAD_GET_STACKSIZE_NP 1
 #define HAVE_PTHREAD_COND_INIT 1
 #define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
 #define HAVE_PTHREAD_SETNAME_NP 1
-#define HAVE_PTHREAD_ATTR_INIT 1
 #define SET_CURRENT_THREAD_NAME(name) pthread_setname_np(name)
 #define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t mc = (uc)->uc_mcontext
 #define HAVE_EXECINFO_H 1
@@ -345,6 +367,8 @@
 #define DLEXT_MAXLEN 7
 #define DLEXT ".bundle"
 #define LIBDIR_BASENAME "lib"
+#define HAVE__SETJMP 1
+#define HAVE_SIGSETJMP 1
 #define RUBY_SETJMP(env) _setjmp((env))
 #define RUBY_LONGJMP(env,val) _longjmp((env),val)
 #define RUBY_JMP_BUF jmp_buf
